imitation.rewards package
=========================

Submodules
----------

imitation.rewards.reward\_nets module
-------------------------------------

.. automodule:: imitation.rewards.reward_nets

imitation.rewards.reward\_wrapper module
----------------------------------------

.. automodule:: imitation.rewards.reward_wrapper

imitation.rewards.serialize
---------------------------

.. automodule:: imitation.rewards.serialize


Module contents
---------------

.. automodule:: imitation.rewards
